================
stis_cti Modules
================

stis_cti.stis_cti()
===================
.. autofunction:: stis_cti.stis_cti

stis_cti.archive_dark_query()
=============================
.. autofunction:: stis_cti.archive_dark_query

stis_cti.viable_ccd_file()
==========================
.. autofunction:: stis_cti.viable_ccd_file

stis_cti.custom_superdark_info()
================================
.. autofunction:: stis_cti.custom_superdark_info

stis_cti.StisPixCteCorr()
=========================
Runs the perturbative part of the correction on a bias-corrected data file.

.. autofunction:: stis_cti.StisPixCteCorr
